#
# spec file for package vulkan-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vulkan-tools
Version:        1.3.280.0
Release:        1.2
Summary:        Diagnostic utilities for Vulkan
License:        Apache-2.0
Group:          Development/Tools/Other
URL:            https://github.com/KhronosGroup/Vulkan-Tools
Source:         https://github.com/KhronosGroup/Vulkan-Tools/archive/refs/tags/vulkan-sdk-%version.tar.gz
Source9:        baselibs.conf
BuildRequires:  cmake >= 3.17
BuildRequires:  gcc-c++ >= 4.8
BuildRequires:  glslang-devel
BuildRequires:  pkg-config
BuildRequires:  python3-base
BuildRequires:  vulkan-volk-devel >= 1.3.280
BuildRequires:  pkgconfig(vulkan) >= 1.3.280
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
Obsoletes:      vulkan < %version-%release
Provides:       vulkan = %version-%release

%description
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

This package contains the Khronos official Vulkan tools and utilities.

%prep
%autosetup -p1 -n Vulkan-Tools-vulkan-sdk-%version

%build
mkdir -p glslang/bin
ln -fsv /usr/bin/glslangValidator glslang/bin/
%cmake
%cmake_build

%install
%cmake_install

%files
%license LICENSE.txt
%_bindir/*

%changelog
* Thu Mar 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.280.0
  * icd: Add AV1 decode support
  * Update linmath to upstream and add degreestoradians
    definition. This fixes bug in linmath function: quat_mul_vec3
* Fri Jan 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.275.0
  * icd: Add vkGetMemoryFdKHR support
  * icd: Add vkGetMemoryHostPointerPropertiesEXT support
  * vulkaninfo: Autogenerate Format list
  * icd: Add basic VkDisplayKHR support
  * icd: Add vkRegisterDisplayEventEXT
  * icd: Add video support
* Fri Oct 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.268.0
  * icd: Add VkSurfacePresentModeCompatibilityEXT support
  * icd: Add second VkCooperativeMatrixPropertiesKHR field
  * vulkaninfo: Support VK_EXT_surface_maintenance1 properly
  * icd: Add VkPhysicalDeviceDriverProperties
* Tue Aug 22 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.261.0
  * icd: Fix OOB writes in QueuePerfCounters
  * icd: Add support for vkGetDescriptorSetLayoutSupport,
    vkGetRenderAreaGranularity, VK_KHR_cooperative_matrix,
    VK_EXT_host_image_copy
  * vulkaninfo: Make -j=<GPU> work
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.250.0
  * vulkaninfo: Issue flush before exiting
* Wed Apr 19 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.247
  * vulkaninfo: Dont enable Direct Driver Loading Ext
  * vkcubepp: Fix custom height not working
* Wed Mar 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.243.0
  * mockicd: Add Support for testing Ray Tracing
  * mockicd: Add Support for testing Video decoding
  * vulkaninfo: Dont enable Direct Driver Loading Ext
* Fri Feb 10 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- Add baselibs.conf. This is useful as 64- and 32-bit Vulkan environments
  need separate drivers and need to be diagnosed separately.
* Sun Jan 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.239.0
  * No end-user visible changes
* Thu Dec 15 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.236.0
  * vulkaninfo: Add Driver Version handling
- Delete 0001-cubepp-Fix-presentKHR-assert.patch (merged)
* Mon Oct 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.231.0
  * Adapt to Vulkan 231 API, but otherwise no interesting changes
- Add 0001-cubepp-Fix-presentKHR-assert.patch
* Mon Aug 22 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.224.0 (497f2326)
  * No changes
- Drop 0001-vulkaninfo-include-wayland-client-because-its-functi.patch
  (merged)
* Mon Aug 15 2022 Dirk Müller <dmueller@suse.com>
- update to branch snapshot SDK-1.3.224 (497f2326)
  * Add issues to the apiext:VK_KHR_dynamic_rendering proposal document
    discussing render area granularity (public issue 1899).
  * Clarify external synchronization requirements for
    ename:VK_DESCRIPTOR_BINDING_UPDATE_AFTER_BIND_BIT and
    ename:VK_DESCRIPTOR_BINDING_UPDATE_UNUSED_WHILE_PENDING_BIT
    elink:VkDescriptorBindingFlagBits and flink:vkUpdateDescriptorSets
    (public issue 1713).
  * Add Vulkan 1.0 valid usage statement for *Subgroup* memory scope to
    <<spirvenv-module-validation-standalone, Standalone SPIR-V Validation>>
    (public merge request 1900).
  * Move "`Hit Kind`" valid usage statement from standalone to runtime
    SPIR-V validation statements (public merge request 1903).
  * Use correct feature in
    ename:VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT
    description (public pull request 1892).
  * GitHub CI: Regenerate and build-test Rust Vulkan bindings (Ash crate)
    (public pull request 1894).
  * Add dependency of apiext:VK_EXT_blend_operation_advanced on
    apiext:VK_KHR_get_physical_device_properties2. (public merge request
    1887).
  * Update xrefs to features so the feature name is used as the link text,
    and marked up consistently. Added a section to the style guide on markup
    of feature xrefs (public issue 1889).
    elink:VK_COLOR_SPACE_PASS_THROUGH_EXT for a linear or non-gamma transfer
    function color space (public merge request 1729).
  * Fix clamp expression for d_{lo} in the
    <<textures-level-of-detail-operation, Level-of-Detail Operation>>
    section (partial fix for public issue 1836).
  * Update <<spirvenv-module-validation-standalone, Standalone SPIR-V
    Validation>> to add explicit valid usage statements for code:Uniform
    objects being read only, and for code:Block decorations (public merge
    request 1879).
  * Add an issue to apiext:VK_KHR_fragment_shader_barycentric for
    interactions with MSAA (public merge request 1881).
  * Fix XML tagging of slink:VkShaderModuleCreateInfo and add an explicit
    valid usage statement so this structure can be validated both as an
    explicit parameter, and as part of the pname:pNext chain of
    slink:VkPipelineShaderStageCreateInfo (public issue 1883, but a broader
    fix in the validation scripts for this case will eventually be
    required).
  * Update pipeline image to move push constants outside of descriptor sets
    (public issue 1867).
  * Correct code:StencilRefLessFrontEXT to code:DepthLess in the early depth
    test portion of the <<fragops, Fragment Operations>> chapter (public
    pull request 1876).
  * Add new driver id ename:VK_DRIVER_ID_MESA_DOZEN (public pull request
    1877).
  * Relax slink:VkRenderPassCreateInfo valid usage statements 02517 and
    02518 to allow ename:VK_SUBPASS_EXTERNAL (public pull request 1878).
  * Add apiext:VK_KHR_maintenance4 relaxed interface valid usage statement
    to the <<spirvenv-module-validation-runtime, Runtime SPIR-V Validation>>
    section (public pull request 1860).
  * Fix field name in slink:VkRenderingAttachmentInfo valid usage statement
    (public pull request 1861).
  * Fix typo in slink:VkFramebufferCreateInfo valid usage statements 04533 /
    04544 (public pull request 1873).
  * Remove duplicate valid usage statement 06060 (public pull request 1874).
  * Rework <<fxvertex-input-address-calculation, Vertex Input Address
    Calculation>> section (public pull request 1869).
  * Split Github CI script into individual jobs to decrease run time (public
    pull request 1870).
  * Clarify meaning of "`private data slot`" for apiext:VK_EXT_private_data
  * Minor markup fix in the <<spirvenv-module-validation-standalone>>
    section (public merge request 1864).
* Thu Jul 21 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-vulkaninfo-include-wayland-client-because-its-functi.patch
* Wed Jun 15 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.216.0
  * cube,vulkaninfo: Add portability_enumeration if present
  * cube: add null check on wl_*_destroy functions
  * vulkaninfo: Set sType in PhysDevGroupProps
  * vkcubepp: Use correct extension for portability enumeration
* Mon Apr 18 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.211.0
  * vulkaninfo: Enable portability extension for device groups
  * vkcube,vulkaninfo: Add portability_enumeration if present
* Sat Feb 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.204.0
  * vulkaninfo: Add Device & driver UUID to summary
* Sat Nov 27 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.198.0
  * vulkaninf: Support 64 bit flags
  * vkcube: Reorder setting of pipeline stage flags
  * vulkaninfo: Prevent drivers from writing out of bounds
* Sun Sep  5 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.189.0
  * vulkaninfo: Fix image format query arguments
* Tue Jul  6 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.182.0
  * vkcube: Fix disturbed rotation after many iterations
* Wed May  5 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.176.0
  * No user-visible changes.
* Sun Feb 28 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.170.0
  * No user-visible changes.
* Wed Feb 10 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.169
  * vkcube: Add options --width and --height
* Sat Jan 23 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.166:
  * build: Update known-good files for 1.2.166 header
  * vkcube: Updated to support portability extension properly
  * vkcube: portabilty extension as text so it builds on all platforms
* Mon Jan 18 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.165
  * No user-visible changes for the Linux port
* Mon Dec 14 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.162 (sdk)
  * No user-visible changes, build changes only.
* Wed Nov 25 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.161
  * vulkaninfo: Add json output for portability subset
  * vulkaninfo: Make json output print extensions
* Mon Sep 28 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.154
  * No user-visible changes.
* Fri Sep 11 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.153
  * No user-visible changes.
* Thu Sep 10 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.152
  * No user-visible changes.
* Wed Aug 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.151
  * vulkaninfo: fix device ext list having bad items
  * vulkaninfo: add `--summary` option that shows basic system info
  * Add support for VK_EXT_directfb_surface extension
* Sun Aug  9 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.148
  * No user-visible changes reported
* Thu Jul  2 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to release 1.2.145
  * scripts: Add default arg for kvt_genvk directory
  * vulkaninfo: fix indent with for present support
  * icd:Correctly Support Vulkan 1.1
  * icd: Cleanup supported VK API version
  * vulkaninfo: fix output style for memory types
  * vulkaninfo: add more asserts to catch bad formatting
  * vulkaninfo: fix ordering issues in generated code
  * scripts: Use named params for generator options
* Thu May 28 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.141
  * vulkaninfo: fix queues not reporting presentation
* Mon Apr 20 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.137
  * vulkaninfo: Fix lack of display throwing on linux
  * cube: Pick non-SRGB surface formats first
  * vulkaninfo: fix app bundle not finding loader
* Wed Apr  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.135
  * vulkaninfo: Fix uninitialized surface capabilities
  * vulkaninfo: dynamically load vulkan
* Wed Feb 19 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.2.133
  * vulkaninfo: support ASTC HDR formats
  * vulkaninfo: Update VkFormat ranges
  * vulkaninfo: new vkconfig_output backdend
  * vulkaninfo: Check for surface extensions
* Fri Feb  7 2020 Antonio Larrosa <alarrosa@suse.com>
-  Really update to 1.2.132
* Mon Feb  3 2020 Jan Engelhardt <jengelh@inai.de>
- Update to 1.2.132
  * vulkaninfo: use GPU version instead of instance
  * vulkaninfo: remove duplicate flags/bitmasks
  * vulkaninfo: erroneous presentation surfaces
* Sun Jan 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.131
  * vulkaninfo: handle previous driver versions
  * vulkaninfo: Make presentation surface names a set
* Thu Dec 12 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.130
  * vulkaninfo: return properly on xcb onnection errors
  * vulkaninfo: check that extensions aren't disabled
  * vkcube: Fix Cube Squishing on Resize
  * vkcube: Replace MoltenVK surfaces with Metal
  * vulkaninfo: Add VK_EXT_metal_surface info
* Thu Nov  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.127
  * vulkaninfo: added more documentation for show-formats
* Sat Oct 26 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.126
  * cube: Try to bind to wl_compositor v4
* Wed Oct 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.124
  * vulkaninfo: Handle absence of device group extension
* Sun Sep 22 2019 Aaron Stern <ukbeast89@protonmail.com>
- Update to new upstream release 1.1.123
  * vulkaninfo: support VK_EXT_subgroup_size_control,
    index_type_uint8_ext, VK_EXT_full_screen_exclusive.
* Wed Aug 21 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release/snapshot 1.1.120
  * vulkaninfo: fix memory leaks from pNext chains
* Fri Jun 28 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.112
  * vulkaninfo: Fix issues 195, 202
  * cube: Add subpass dependencies
  * vulkaninfo: Fix HTML format for multi-GPU computer
* Tue Jun  4 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.108
  * vulkaninfo: Fix uninitialized VkDevice pQueuePriorities
  * vulkaninfo: Add VK_KHR_depth_stencil_resolve,
    VK_EXT_buffer_device_address, VK_EXT_memory_budget output,
    VK_EXT_memory_priority output, VK_EXT_ycbcr_image_arrays,
    VK_EXT_host_query_reset, VK_KHR_surface_protected_capabilities.
  * vulkaninfo: Check support for surface extensions before
    using them
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream snapshot 1.1.102.git10 (eaf30e89)
  * vulkaninfo: Fix uninitialized VkDevice pQueuePriorities
* Mon Feb 18 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.100
  * vulkaninfo: print VK_MEMORY_PROPERTY_PROTECTED_BIT
  * Fix vulkaninfo segfault on 1.0 devices
  * vulkaninfo: shorten format dump in console
  * vulkaninfo: Remove non-existent device extension
* Thu Jan 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.97.0
  * vulkaninfo: Update enums to 1.1.89 headers
  * vulkaninfo: Add VK_KHR_shader_atomic_int64,
    VK_EXT_transform_feedback, VK_EXT_scalar_block_layout,
    VK_EXT_fragment_density_map
  * Fix vulkaninfo segfault on 1.0 devices
- Remove 0001-build-add-missing-wayland-client-search-path-for-moc.patch
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release+snapshot 1.1.96+git6
  * vulkaninfo: Add VK_EXT_pci_bus_info
  * vulkaninfo: Update enums to 1.1.89 headers
* Sun Dec  2 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.92
  * vulkaninfo: Add wayland surface extension support
  * vulkaninfo: Describe multiple surface extensions
* Mon Nov 12 2018 Jan Engelhardt <jengelh@inai.de>
- Split vulkan SRPM -> vulkan-tools SRPM following a
  repository split upstream.
- Update to new snapshot 1.1.91
  * vulkaninfo: Add core 1.1 extensions
  * vulkaninfo: Add VK_KHR_maintenance3 support
  * vulkaninfo: Add device+driver UUID/LUID/NodeMask
  * vulkaninfo: Add VK_KHR_8bit_storage support
- Add 0001-build-add-missing-wayland-client-search-path-for-moc.patch
* Sat Aug 25 2018 jengelh@inai.de
- Update to new snapshot 1.1.73
  * layers: Removed obsolete (and duplicate) VUIDs
  * layers: Make unique_objects ID map global
  * layers: Add VUIDs for VK_KHR_incremental_present
  * layers: Add canonical/unique ID to pipeline layout
  * layers: Add support for StorageBuffer storage class
  * loader: Add new core 1.1 entry points
  * loader: Update loader for Vulkan 1.1
  * vulkaninfo: Add core 1.1 extensions
* Fri Mar  9 2018 crrodriguez@opensuse.org
- Skip building tests that are neither packaged nor ran.
* Fri Mar  9 2018 crrodriguez@opensuse.org
- vulkan-devel has missing dependencies, this causes further
  confusion down the dependency chain, fix it by adding
  the required X and wayland components
* Wed Mar  7 2018 jengelh@inai.de
- Update to new snapshot 1.1.70
  * Support for Vulkan 1.1 (Subgroup operations)
* Wed Feb  7 2018 jengelh@inai.de
- Update to new snapshot 1.0.68
  * layers: add image layout validation to vkCmdBlitImage()
  * layers: Add VK_EXT_validation_cache implementation for shaders
  * layers: Add layer metadata for EXT_validation_cache extension
  * layers: Add descriptor limit checks to vkCreatePipelineLayout()
  * layers: Create instance & device extension lists
- Add no-git.diff
* Wed Jan 10 2018 jengelh@inai.de
- Drop ImageMagick build-time requirement
* Thu Nov 16 2017 jengelh@inai.de
- Update to new snapshot 1.0.65
  * The VK_EXT_global_priority extension extends the concept of
    device-scope queue priorities to now be a system-wide scope.
    The global/system-wide priority level takes priority over the
    per-process queue priorities.
  * New extension VK_KHR_bind_memory2: This extension allows
    vkBindBufferMemory and vkBindImageMemory to support multiple
    bindings to be performed at once while also being more
    extensible.
  * New extension VK_KHR_image_format_list: Provides a list of
    all formats that can be used with a Vulkan image when it is
    created.
  * New extension VK_KHR_maintenance2: Adds in various changes
    that were left out of Vulkan previously. These maintenance
    updates allow implementations to express clipping behavior of
    points, creating images with usage flags that may not be
    supported for the base image's format, creating uncompressed
    image views of compressed images, two new image layouts for
    depth stencil images, and other minor changes.
  * New extension VK_KHR_sampler_ycbcr_conversion: Support to
    perform specified color space conversions during texture
    sampling operations.
- Drop 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
  (included upstream)
* Sat Aug 12 2017 jengelh@inai.de
- Update to new upstream release 1.0.57.0
  * loader: Do not enumerate extensions from disabled implicit
    layers
  * layers:Handle ALL_*_BIT pipe stage barrier validation
  * LVL: Add validation check for CreateImageView
  * loader: Remove executable stack from libvulkan.so
  * layers: Fix mismatched new[] / delete
  * layers: Add new PV ranged enum validation function
  * layers: Don't do bogus transitions in invalidateCommandBuffers
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 1.0.54
  * Fix a few potential overruns
  * Configurable fallback search paths
  * Validate device features: imageCubeArray, dualSrcBlend,
    multiDrawIndirect, depthClamp, depthBounds, alphaToOne,
    samplerAnisotropy.
  * Add compressed texture query utils
  * Add feature checks for textureCompressionETC2,
    textureCompressionASTC_LDR, textureCompressionBC,
    sparseBinding device, sparseResidencyBuffer,
    sparseResidencyAliased, depthBiasClamp.
  * Remove deprecated KHX extension from OT/PV
  * Support CapabilityGeometryShaderPassThroughNV and
    CapabilitySampleMaskOverrideCoverage.
  * Support the viewport_array2, shader_subgroup_ballot and
    shader_subgroup_vote ext shader caps.
  * Change size of X8_D24_UNORM_PACK32 and D32_SFLOAT_S8_UINT
- Add 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
* Mon Feb 20 2017 jengelh@inai.de
- Update to new upstream release 1.0.41
  * layers: Move image struct into cv_types header
  * layers: Move CreateImage validation into core_val
  * layers: Move DestroyImage code into buffer module
  * layers: Move CreateRenderPass format check to PV
  * layers: Rename misleading renderpass structure var
  * layers:Move gfx pipe check to create time
  * layers: Move image validation support to buffer_val
  * layers: Add enable for NV_GLSL_SHADER extension
- Add baselibs.conf [needed by libgtk-4-0]
* Mon Jan 30 2017 jengelh@inai.de
- Update to new upstream release 1.0.39.1
  * layers: Add tracking for VK_KHR_display extension in PV
  * layers: Add null checks to RetireWorkOnQueue
  * vulkaninfo: fix segfault when DISPLAY is not set
  * layers: Complete support for VK_KHR_Display ext
* Mon Oct 31 2016 jengelh@inai.de
- Update to 1.0.32.g28
  * vkjson: Rename VkJsonAllProperties to VkJsonDevice
  * loader: Fix json output of escape chars
  * loader: Fix segfault in vulkaninfo
  * Add vulkan C++ header
- Remove 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch
  (upstreamed).
* Mon Jun 13 2016 jengelh@inai.de
- Update to new snapshot 1.0.3.g5493
  * Added helpers: getSwapchainNode(), getSwapchainFromImage(),
  getImageNode(), getImageViewData(), getSamplerNode(),
  getBufferViewInfo(), getBufferNode().
- Resolve build failure stemming from new glslang version
- Add 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch.
  These were in a prior tarball made from a Fedora git,
  but we since switched to the upstream git.
* Wed Feb 17 2016 jengelh@inai.de
- Initial package (version 1.0.3.g19) for build.opensuse.org
